@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2004 Imendio AB
+ * Copyright (C) 2004-2006 Imendio AB
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -26,13 +26,14 @@
 #include <libxml/tree.h>
 
 #include "libgossip-marshal.h"
-
+#include "gossip-utils.h"
 #include "gossip-account-manager.h"
 
 #define ACCOUNTS_XML_FILENAME "accounts.xml"
 #define ACCOUNTS_DTD_FILENAME "gossip-account.dtd"
 
-#define d(x)
+#define DEBUG_MSG(x) 
+/* #define DEBUG_MSG(args) g_printerr args ; g_printerr ("\n"); */
 
 #define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GOSSIP_TYPE_ACCOUNT_MANAGER, GossipAccountManagerPriv))
 
@@ -53,23 +54,19 @@ struct _GossipAccountManagerPriv {
 enum {
 	ACCOUNT_ADDED,
 	ACCOUNT_REMOVED, 
-	ACCOUNT_ENABLED,
 	NEW_DEFAULT,
 	LAST_SIGNAL
 };
 
 
 static void     account_manager_finalize             (GObject               *object);
-static void     account_manager_account_enabled_cb   (GossipAccount         *account,
-						      GParamSpec            *arg1,
-						      GossipAccountManager  *manager);
 static gboolean account_manager_get_all              (GossipAccountManager  *manager);
 static gboolean account_manager_file_parse           (GossipAccountManager  *manager,
 						      const gchar           *filename);
 static gboolean account_manager_file_save            (GossipAccountManager  *manager);
 
 
-static guint  signals[LAST_SIGNAL] = {0};
+static guint signals[LAST_SIGNAL] = {0};
 
 
 G_DEFINE_TYPE (GossipAccountManager, gossip_account_manager, G_TYPE_OBJECT);
@@ -82,7 +79,6 @@ gossip_account_manager_class_init (GossipAccountManagerClass *klass)
 
 	object_class->finalize = account_manager_finalize;
 
-
 	signals[ACCOUNT_ADDED] = 
 		g_signal_new ("account-added",
                               G_TYPE_FROM_CLASS (klass),
@@ -101,15 +97,6 @@ gossip_account_manager_class_init (GossipAccountManagerClass *klass)
 			      libgossip_marshal_VOID__OBJECT,
 			      G_TYPE_NONE,
 			      1, GOSSIP_TYPE_ACCOUNT);
-        signals[ACCOUNT_ENABLED] = 
-		g_signal_new ("account-enabled",
-			      G_TYPE_FROM_CLASS (klass),
-                              G_SIGNAL_RUN_LAST,
-			      0, 
-			      NULL, NULL,
-			      libgossip_marshal_VOID__OBJECT,
-			      G_TYPE_NONE,
-			      1, GOSSIP_TYPE_ACCOUNT);
         signals[NEW_DEFAULT] = 
 		g_signal_new ("new-default",
 			      G_TYPE_FROM_CLASS (klass),
@@ -185,14 +172,10 @@ gossip_account_manager_add (GossipAccountManager *manager,
 		type = gossip_account_get_type (account);
 		name = gossip_account_get_name (account);
 
-		d(g_print ("Account Manager: Adding %s %s account with name:'%s'\n", 
-			   gossip_account_get_enabled (account) ? "enabled" : "disabled", 
+		DEBUG_MSG (("Account Manager: Adding %s account with name:'%s'", 
 			   gossip_account_get_type_as_str (type), 
 			   name));
 		
-		g_signal_connect (account, "notify::enabled", 
-				  G_CALLBACK (account_manager_account_enabled_cb), manager);
-
 		priv->accounts = g_list_append (priv->accounts, g_object_ref (account));
 
 		g_signal_emit (manager, signals[ACCOUNT_ADDED], 0, account);
@@ -214,13 +197,9 @@ gossip_account_manager_remove (GossipAccountManager *manager,
 
 	priv = GET_PRIV (manager);
 
- 	d(g_print ("Account Manager: Removing account with name:'%s'\n",  
+ 	DEBUG_MSG (("Account Manager: Removing account with name:'%s'",  
  		   gossip_account_get_name (account)));
 
-	g_signal_handlers_disconnect_by_func (account, 
-					      account_manager_account_enabled_cb, 
-					      manager);
-
 	priv->accounts = g_list_remove (priv->accounts, account);
 	
 	g_signal_emit (manager, signals[ACCOUNT_REMOVED], 0, account);
@@ -228,14 +207,6 @@ gossip_account_manager_remove (GossipAccountManager *manager,
 	g_object_unref (account);
 }
 
-static void
-account_manager_account_enabled_cb (GossipAccount        *account,
-				    GParamSpec           *arg1,
-				    GossipAccountManager *manager)
-{
-	g_signal_emit (manager, signals[ACCOUNT_ENABLED], 0, account);
-}
-
 GList *
 gossip_account_manager_get_accounts (GossipAccountManager *manager)
 {
@@ -303,7 +274,7 @@ gossip_account_manager_set_overridden_default (GossipAccountManager *manager,
 
 	priv = GET_PRIV (manager);
 
- 	d(g_print ("Account Manager: Setting overriding default account with name:'%s'\n",  
+ 	DEBUG_MSG (("Account Manager: Setting overriding default account with name:'%s'",  
  		   name)); 
 
 	g_free (priv->default_name_override);
@@ -322,7 +293,7 @@ gossip_account_manager_set_default (GossipAccountManager *manager,
 
 	priv = GET_PRIV (manager);
 	
- 	d(g_print ("Account Manager: Setting default account with name:'%s'\n",  
+ 	DEBUG_MSG (("Account Manager: Setting default account with name:'%s'",  
  		   gossip_account_get_name (account))); 
 
 	name = gossip_account_get_name (account);
@@ -387,7 +358,7 @@ gossip_account_manager_store (GossipAccountManager *manager)
 {
 	g_return_val_if_fail (GOSSIP_IS_ACCOUNT_MANAGER (manager), FALSE);
 
- 	d(g_print ("Account Manager: Saving accounts\n"));  
+ 	DEBUG_MSG (("Account Manager: Saving accounts"));  
 	
 	return account_manager_file_save (manager);
 }
@@ -403,8 +374,6 @@ account_manager_get_all (GossipAccountManager *manager)
 	gchar                    *dir;
 	gchar                    *file_with_path = NULL;
 
-	g_return_val_if_fail (GOSSIP_IS_ACCOUNT_MANAGER (manager), FALSE);
-
 	priv = GET_PRIV (manager);
 
 	/* Use default if no file specified. */
@@ -443,7 +412,7 @@ account_manager_parse_account (GossipAccountManager *manager,
 	gchar             *name, *id, *password;
 	gchar             *server;
 	guint16            port;
-	gboolean           enabled, auto_connect, use_ssl, use_proxy;
+	gboolean           auto_connect, use_ssl, use_proxy;
 
 	/* Default values. */
 	type = GOSSIP_ACCOUNT_TYPE_JABBER;
@@ -452,7 +421,6 @@ account_manager_parse_account (GossipAccountManager *manager,
 	password = NULL;
 	server = NULL;
 	port = 5222;
-	enabled = TRUE;
 	auto_connect = TRUE;
 	use_ssl = FALSE;
 	use_proxy = FALSE;
@@ -491,14 +459,6 @@ account_manager_parse_account (GossipAccountManager *manager,
 			}
 			xmlFree (str);
 		}
-		else if (strcmp (tag, "enabled") == 0) {
-			if (strcmp (str, "yes") == 0) {
-				enabled = TRUE;
-			} else {
-				enabled = FALSE;
-			}
-			xmlFree (str);
-		}
 		else if (strcmp (tag, "auto_connect") == 0) {
 			if (strcmp (str, "yes") == 0) {
 				auto_connect = TRUE;
@@ -533,7 +493,6 @@ account_manager_parse_account (GossipAccountManager *manager,
 					"name", name,
 					"id", id,
 					"port", port,
-					"enabled", enabled,
 					"auto_connect", auto_connect,
 					"use_ssl", use_ssl,
 					"use_proxy", use_proxy,
@@ -568,25 +527,22 @@ account_manager_file_parse (GossipAccountManager *manager,
 	xmlNodePtr                node;
 	gchar                    *str;
 
-	g_return_val_if_fail (GOSSIP_IS_ACCOUNT_MANAGER (manager), FALSE);
-	g_return_val_if_fail (filename != NULL, FALSE);
-
 	priv = GET_PRIV (manager);
 	
-	d(g_print ("Account Manager: Attempting to parse file:'%s'...\n", filename));
+	DEBUG_MSG (("Account Manager: Attempting to parse file:'%s'...", filename));
 
  	ctxt = xmlNewParserCtxt ();
 
 	/* Parse and validate the file. */
-	doc = xmlCtxtReadFile (ctxt, filename, NULL, XML_PARSE_DTDVALID);	
+	doc = xmlCtxtReadFile (ctxt, filename, NULL, 0);
 	if (!doc) {
 		g_warning ("Failed to parse file:'%s'", filename);
 		xmlFreeParserCtxt (ctxt);
 		return FALSE;
 	}
 
-	if (!ctxt->valid) {
-		g_warning ("Failed to validate file:'%s'",  filename);
+	if (!gossip_utils_xml_validate (doc, ACCOUNTS_DTD_FILENAME)) {
+		g_warning ("Failed to validate file:'%s'", filename);
 		xmlFreeDoc(doc);
 		xmlFreeParserCtxt (ctxt);
 		return FALSE;
@@ -612,10 +568,10 @@ account_manager_file_parse (GossipAccountManager *manager,
 		node = node->next;
 	}
 	
-	d(g_print ("Account Manager: Parsed %d accounts\n", 
+	DEBUG_MSG (("Account Manager: Parsed %d accounts", 
 		   g_list_length (priv->accounts)));
 
-	d(g_print ("Account Manager: Default account is:'%s'\n", 
+	DEBUG_MSG (("Account Manager: Default account is:'%s'", 
 		   priv->default_name));
 	
 	xmlFreeDoc(doc);
@@ -637,8 +593,6 @@ account_manager_file_save (GossipAccountManager *manager)
 	gchar                    *xml_dir;
 	gchar                    *xml_file;
 					
-	g_return_val_if_fail (GOSSIP_IS_ACCOUNT_MANAGER (manager), FALSE);
-
 	priv = GET_PRIV (manager);
 	
 	if (priv->accounts_file_name) {
@@ -655,19 +609,19 @@ account_manager_file_save (GossipAccountManager *manager)
 
 	dtd_file = g_build_filename (DTDDIR, ACCOUNTS_DTD_FILENAME, NULL);
 
-	doc = xmlNewDoc (BAD_CAST "1.0");
-	root = xmlNewNode (NULL, BAD_CAST "accounts");
+	doc = xmlNewDoc ("1.0");
+	root = xmlNewNode (NULL, "accounts");
 	xmlDocSetRootElement (doc, root);
 
-	dtd = xmlCreateIntSubset (doc, BAD_CAST "accounts", NULL, BAD_CAST dtd_file);
+	dtd = xmlCreateIntSubset (doc,"accounts", NULL,dtd_file);
 
 	if (!priv->default_name) {
 		priv->default_name = g_strdup ("Default");
 	}
 	
 	xmlNewChild (root, NULL, 
-		     BAD_CAST "default", 
-		     BAD_CAST priv->default_name);
+		    "default", 
+		    priv->default_name);
 
 	accounts = gossip_account_manager_get_accounts (manager);
 
@@ -687,25 +641,24 @@ account_manager_file_save (GossipAccountManager *manager)
 	
 		port = g_strdup_printf ("%d", gossip_account_get_port (account));
 
-		node = xmlNewChild (root, NULL, BAD_CAST "account", NULL);
-		xmlNewChild (node, NULL, BAD_CAST "type", BAD_CAST type);
-		xmlNewChild (node, NULL, BAD_CAST "name", BAD_CAST gossip_account_get_name (account));
-		xmlNewChild (node, NULL, BAD_CAST "id", BAD_CAST gossip_account_get_id (account));
+		node = xmlNewChild (root, NULL, "account", NULL);
+		xmlNewChild (node, NULL, "type", type);
+		xmlNewTextChild (node, NULL, "name", gossip_account_get_name (account));
+		xmlNewTextChild (node, NULL, "id", gossip_account_get_id (account));
 
-		xmlNewChild (node, NULL, BAD_CAST "password", BAD_CAST gossip_account_get_password (account));
-		xmlNewChild (node, NULL, BAD_CAST "server", BAD_CAST gossip_account_get_server (account));
-		xmlNewChild (node, NULL, BAD_CAST "port", BAD_CAST port);
+		xmlNewTextChild (node, NULL, "password", gossip_account_get_password (account));
+		xmlNewTextChild (node, NULL, "server", gossip_account_get_server (account));
+		xmlNewChild (node, NULL, "port", port);
 
-		xmlNewChild (node, NULL, BAD_CAST "enabled", BAD_CAST (gossip_account_get_enabled (account) ? "yes" : "no"));
-		xmlNewChild (node, NULL, BAD_CAST "auto_connect", BAD_CAST (gossip_account_get_auto_connect (account) ? "yes" : "no"));
-		xmlNewChild (node, NULL, BAD_CAST "use_ssl", BAD_CAST (gossip_account_get_use_ssl (account) ? "yes" : "no"));
-		xmlNewChild (node, NULL, BAD_CAST "use_proxy", BAD_CAST (gossip_account_get_use_proxy (account) ? "yes" : "no"));
+		xmlNewChild (node, NULL, "auto_connect", gossip_account_get_auto_connect (account) ? "yes" : "no");
+		xmlNewChild (node, NULL, "use_ssl", gossip_account_get_use_ssl (account) ? "yes" : "no");
+		xmlNewChild (node, NULL, "use_proxy", gossip_account_get_use_proxy (account) ? "yes" : "no");
 
 		g_free (type);
 		g_free (port);
 	}
 
-	d(g_print ("Account Manager: Saving file:'%s'\n", xml_file));
+	DEBUG_MSG (("Account Manager: Saving file:'%s'", xml_file));
 	xmlSaveFormatFileEnc (xml_file, doc, "utf-8", 1);
 	xmlFreeDoc (doc);
 
