@@ -37,14 +37,15 @@
 #include "gossip-theme-manager.h"
 #include "gossip-app.h"
 
+#define DEBUG_MSG(x) 
+/* #define DEBUG_MSG(args) g_printerr args ; g_printerr ("\n"); */
+
 /* Number of seconds between timestamps when using normal mode, 5 minutes. */
 #define TIMESTAMP_INTERVAL 300
 
 /* Maximum lines in any chat buffer, see bug #141292. */
 #define MAX_LINES 1000
 
-#define d(x)
-
 
 typedef enum {
 	BLOCK_TYPE_NONE,
@@ -174,6 +175,11 @@ static gint num_smileys = G_N_ELEMENTS (smileys);
 static void       gossip_chat_view_class_init          (GossipChatViewClass      *klass);
 static void       gossip_chat_view_init                (GossipChatView           *view);
 static void       chat_view_finalize                   (GObject                  *object);
+static gboolean   chat_view_drag_motion                (GtkWidget                *widget,
+							GdkDragContext           *context,
+							gint                      x,
+							gint                      y,
+							guint                     time);
 static void       chat_view_size_allocate              (GtkWidget                *widget,
 							GtkAllocation            *alloc);
 static void       chat_view_setup_tags                 (GossipChatView           *view);
@@ -247,6 +253,7 @@ gossip_chat_view_class_init (GossipChatViewClass *klass)
 
 	object_class->finalize = chat_view_finalize;
 	widget_class->size_allocate = chat_view_size_allocate;
+	widget_class->drag_motion = chat_view_drag_motion;
 }
 
 static void
@@ -297,6 +304,20 @@ chat_view_finalize (GObject *object)
 	G_OBJECT_CLASS (gossip_chat_view_parent_class)->finalize (object);
 }
 
+static gboolean
+chat_view_drag_motion (GtkWidget        *widget,
+		       GdkDragContext   *context,
+		       gint              x,
+		       gint              y,
+		       guint             time)
+{
+	/* Don't handle drag motion, since we don't want the view to scroll as
+	 * the result of dragging something across it.
+	 */
+	
+	return TRUE;
+}
+
 static void
 chat_view_size_allocate (GtkWidget     *widget,
 			 GtkAllocation *alloc)
@@ -1064,7 +1085,7 @@ chat_view_maybe_append_fancy_header (GossipChatView *view,
 
 	contact = gossip_message_get_sender (msg);
 	
-	d(g_print ("ChatView: Maybe add fancy header\n"));
+	DEBUG_MSG (("ChatView: Maybe add fancy header"));
 
 	if (from_self) {
 		name = gossip_contact_get_name (my_contact);
@@ -1147,7 +1168,7 @@ chat_view_append_irc_action (GossipChatView *view,
 
 	priv = view->priv;
 
-	d(g_print ("ChatView: Add IRC action\n"));
+	DEBUG_MSG (("ChatView: Add IRC action"));
 
 	/* Skip the "/me ". */
 	if (from_self) {
@@ -1201,7 +1222,7 @@ chat_view_append_fancy_action (GossipChatView *view,
 
 	priv = view->priv;
 
-	d(g_print ("ChatView: Add fancy action\n"));
+	DEBUG_MSG (("ChatView: Add fancy action"));
 
 	contact = gossip_message_get_sender (msg);
 
@@ -1250,7 +1271,7 @@ chat_view_append_irc_message (GossipChatView *view,
 
 	priv = view->priv;
 
-	d(g_print ("ChatView: Add IRC message\n"));
+	DEBUG_MSG (("ChatView: Add IRC message"));
 
 	body = gossip_message_get_body (msg);
 
