@@ -42,8 +42,9 @@
 #include "gossip-stock.h"
 #include "gossip-ui-utils.h"
 
+#define DEBUG_MSG(x) 
+/* #define DEBUG_MSG(args) g_printerr args ; g_printerr ("\n"); */
 
-#define d(x)
 
 static void       gossip_chat_window_class_init        (GossipChatWindowClass *klass);
 static void       gossip_chat_window_init              (GossipChatWindow      *window);
@@ -55,6 +56,8 @@ static void       chat_window_accel_cb                 (GtkAccelGroup         *a
 							guint                  key,
 							GdkModifierType        mod,
 							GossipChatWindow      *window);
+static void       chat_window_close_clicked_cb         (GtkWidget             *button,
+							GossipChat            *chat);
 static GtkWidget *chat_window_create_label             (GossipChatWindow      *window,
 							GossipChat            *chat);
 static void       chat_window_update_status            (GossipChatWindow      *window,
@@ -170,8 +173,7 @@ struct _GossipChatWindowPriv {
 };
 
 
-static gpointer  parent_class;
-static GList    *chat_windows = NULL;
+static GList *chat_windows = NULL;
 
 
 static guint tab_accel_keys[] = {
@@ -197,9 +199,16 @@ static void
 gossip_chat_window_class_init (GossipChatWindowClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	parent_class = g_type_class_peek_parent (klass);
 
-	object_class->finalize	   = gossip_chat_window_finalize;
+	object_class->finalize = gossip_chat_window_finalize;
+	
+	/* Set up a style for the close button with no focus padding. */
+	gtk_rc_parse_string (
+		"style \"gossip-close-button-style\"\n"
+		"{\n"
+		"  GtkWidget::focus-padding = 0\n"
+		"}\n"
+		"widget \"*.gossip-close-button\" style \"gossip-close-button-style\"");
 }
 
 static void
@@ -434,7 +443,7 @@ gossip_chat_window_finalize (GObject *object)
 	gtk_widget_destroy (window->priv->dialog);
 	g_free (window->priv);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gossip_chat_window_parent_class)->finalize (object);
 }
 
 static GdkPixbuf *
@@ -491,6 +500,16 @@ chat_window_accel_cb (GtkAccelGroup    *accelgroup,
 	}
 }
 
+static void
+chat_window_close_clicked_cb (GtkWidget  *button,
+			      GossipChat *chat)
+{
+	GossipChatWindow *window;
+
+	window = gossip_chat_get_window (chat);
+	gossip_chat_window_remove_chat (window, chat);
+}
+
 static GtkWidget *
 chat_window_create_label (GossipChatWindow *window,
 			  GossipChat       *chat)
@@ -498,11 +517,15 @@ chat_window_create_label (GossipChatWindow *window,
 	GossipChatWindowPriv *priv;
 	GtkWidget            *hbox;
 	GtkWidget            *name_label;
-	GtkWidget            *status_img;
+	GtkWidget            *status_image;
+	GtkWidget            *close_button;
+	GtkWidget            *close_image;
 	const gchar          *name;
 	GtkWidget            *event_box; 
+	GtkWidget            *event_box_hbox; 
 	PangoAttrList        *attr_list;
 	PangoAttribute       *attr;
+	gint                  w, h;
 
 	priv = window->priv;
 	
@@ -527,21 +550,50 @@ chat_window_create_label (GossipChatWindow *window,
 	gtk_misc_set_alignment (GTK_MISC (name_label), 0.0, 0.5);
 	g_object_set_data (G_OBJECT (chat), "label", name_label); 
 
-	status_img = gtk_image_new ();
+	status_image = gtk_image_new ();
 
-	g_object_set_data (G_OBJECT (chat), "chat-window-status-img", status_img);
+	g_object_set_data (G_OBJECT (chat), "chat-window-status-img", status_image);
   	g_object_set_data (G_OBJECT (chat), "chat-window-tooltip-widget", event_box);
 
 	chat_window_update_tooltip (window, chat);
 
-	gtk_box_pack_start (GTK_BOX (hbox), status_img, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (hbox), name_label, TRUE, TRUE, 0);
+	event_box_hbox = gtk_hbox_new (FALSE, 0);
 
- 	gtk_container_add (GTK_CONTAINER (event_box), hbox);
+	gtk_box_pack_start (GTK_BOX (event_box_hbox), status_image, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (event_box_hbox), name_label, TRUE, TRUE, 0);
 
- 	gtk_widget_show_all (event_box);
+	close_button = gtk_button_new ();
+	gtk_button_set_relief (GTK_BUTTON (close_button), GTK_RELIEF_NONE);
 
-	return event_box;
+	/* Set the name to make the special rc style match. */
+	gtk_widget_set_name (close_button, "gossip-close-button");
+	
+	close_image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
+	gtk_container_add (GTK_CONTAINER (close_button), close_image);
+
+	gtk_container_set_border_width (GTK_CONTAINER (close_button), 0);
+
+	/* We don't want focus/keynav for the button to avoid clutter, and
+	 * Ctrl-W works anyway.
+	 */
+	GTK_WIDGET_UNSET_FLAGS (close_button, GTK_CAN_FOCUS);
+	GTK_WIDGET_UNSET_FLAGS (close_button, GTK_CAN_DEFAULT);
+
+	/* Make sure the button isn't too big. */
+	gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &w, &h);
+	gtk_widget_set_size_request (close_button, w + 2, h + 2);
+ 
+	gtk_box_pack_start (GTK_BOX (hbox), event_box_hbox, TRUE, TRUE, 0);
+	gtk_box_pack_end (GTK_BOX (hbox), close_button, FALSE, FALSE, 0);
+
+	g_signal_connect (close_button,
+			  "clicked",
+			  G_CALLBACK (chat_window_close_clicked_cb),
+			  chat);
+
+	gtk_widget_show_all (hbox);
+
+	return hbox;
 }
 
 static void
@@ -914,7 +966,7 @@ chat_window_delete_event_cb (GtkWidget        *dialog,
 {
 	GList *list, *l;
 
-	d(g_print ("Chat Window: Delete event received\n"));
+	DEBUG_MSG (("Chat Window: Delete event received"));
 
 	list = g_list_copy (window->priv->chats);
 
@@ -1069,7 +1121,7 @@ chat_window_tab_added_cb (GossipNotebook   *notebook,
 
 	priv = window->priv;
 
-	d(g_print ("Chat Window: Tab added\n"));
+	DEBUG_MSG (("Chat Window: Tab added"));
 
 	chat = g_object_get_data (G_OBJECT (child), "chat");
 
@@ -1110,7 +1162,7 @@ chat_window_tab_removed_cb (GossipNotebook   *notebook,
 {
 	GossipChat *chat;
 
-	d(g_print ("Chat Window: Tab removed\n"));
+	DEBUG_MSG (("Chat Window: Tab removed"));
 
 	chat = g_object_get_data (G_OBJECT (child), "chat");
 	
@@ -1147,7 +1199,7 @@ chat_window_tab_detached_cb (GossipNotebook   *notebook,
 	GossipChat	 *chat;
 	gint              x, y;
 
-	d(g_print ("Chat Window: Tab detached\n"));
+	DEBUG_MSG (("Chat Window: Tab detached"));
 
 	chat = g_object_get_data (G_OBJECT (child), "chat");
 	new_window = gossip_chat_window_new ();
@@ -1162,6 +1214,8 @@ chat_window_tab_detached_cb (GossipNotebook   *notebook,
 	
 	gossip_chat_window_remove_chat (window, chat);
 	gossip_chat_window_add_chat (new_window, chat);
+
+	gtk_widget_show (new_window->priv->dialog);
 }
 
 static void
@@ -1199,12 +1253,15 @@ chat_window_drag_data_received (GtkWidget        *widget,
 	const gchar       *id;
 
 	id = (const gchar*) selection->data;
-	d(g_print ("Chat Window: Received drag & drop contact from roster with id:'%s'\n", id));
+	DEBUG_MSG (("Chat Window: Received drag & drop contact "
+		    "from roster with id:'%s'", 
+		    id));
 
 	contact = gossip_session_find_contact (gossip_app_get_session (), id);
 	
 	if (!contact) {
-		d(g_print ("Chat Window: No contact found associated with drag & drop\n"));
+		DEBUG_MSG (("Chat Window: No contact found associated "
+			    "with drag & drop"));
 		return;
 	}
 
@@ -1261,14 +1318,14 @@ gossip_chat_window_add_chat (GossipChatWindow *window,
 {
 	GtkWidget *label;
 
-	d(g_print ("Chat Window: Adding chat\n"));
+	DEBUG_MSG (("Chat Window: Adding chat"));
 
 	label = chat_window_create_label (window, chat);
 
 	if (g_list_length (window->priv->chats) == 0) {
 		gint width, height;
 
-		/* first chat, resize the window to its preferred size */
+		/* First chat, resize the window to its preferred size. */
 		gossip_chat_get_geometry (chat, &width, &height);
 		gtk_window_resize (GTK_WINDOW (window->priv->dialog), width, height);
 	}
@@ -1287,7 +1344,7 @@ void
 gossip_chat_window_remove_chat (GossipChatWindow *window,
 				GossipChat	 *chat)
 {
-	d(g_print ("Chat Window: Removing chat\n"));
+	DEBUG_MSG (("Chat Window: Removing chat"));
 
 	gossip_notebook_remove_page (GOSSIP_NOTEBOOK (window->priv->notebook),
 				     gossip_chat_get_widget (chat));
