@@ -20,7 +20,9 @@
 
 #include <string.h>
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
@@ -40,7 +42,12 @@
 #include "gossip-sound.h"
 #include "gossip-stock.h"
 
-#define d(x)
+#ifdef HAVE_LIBNOTIFY
+#include "gossip-notify.h"
+#endif
+
+#define DEBUG_MSG(x)  
+/* #define DEBUG_MSG(args) g_printerr args ; g_printerr ("\n");  */
 
 /* Flashing delay for icons (milliseconds). */
 #define FLASH_TIMEOUT 500
@@ -138,6 +145,10 @@ static void     contact_list_contact_presence_updated_cb (GossipSession     *ses
 static void     contact_list_contact_removed_cb          (GossipSession     *session,
 							  GossipContact     *contact,
 							  GossipContactList *list);
+static void     contact_list_contact_composing_cb        (GossipSession     *session,
+							  GossipContact     *contact,
+							  gboolean           composing,
+							  GossipContactList *list);
 static void     contact_list_contact_set_active          (GossipContactList *list,
 							  GossipContact     *contact,
 							  gboolean           active,
@@ -277,6 +288,7 @@ enum {
 	COL_IS_GROUP,
 	COL_IS_ACTIVE,
 	COL_IS_ONLINE,
+	COL_IS_COMPOSING,
 	COL_COUNT
 };
 
@@ -520,6 +532,10 @@ gossip_contact_list_init (GossipContactList *list)
 			  "contact-removed",
 			  G_CALLBACK (contact_list_contact_removed_cb),
 			  list);
+	g_signal_connect (gossip_app_get_session (),
+			  "composing-event",
+			  G_CALLBACK (contact_list_contact_composing_cb),
+			  list);
 
 	/* connect to event manager signals */
 	g_signal_connect (gossip_app_get_event_manager (),
@@ -599,7 +615,7 @@ contact_list_set_property (GObject      *object,
 static void
 contact_list_connected_cb (GossipSession *session, GossipContactList *list)
 {
-	d(g_print ("ContactList: Connected\n"));
+	DEBUG_MSG (("ContactList: Connected"));
 
 	g_timeout_add (ACTIVE_USER_WAIT_TO_ENABLE_TIME, 
 		       (GSourceFunc) contact_list_show_active_users_cb,
@@ -627,7 +643,7 @@ contact_list_contact_added_cb (GossipSession     *session,
 
 	priv = list->priv;
 
-	d(g_print ("ContactList: Contact added: %s\n",
+	DEBUG_MSG (("ContactList: Contact added: %s",
 		   gossip_contact_get_name (contact)));
 
 	if (!priv->show_offline && !gossip_contact_is_online (contact)) {
@@ -655,15 +671,15 @@ contact_list_contact_updated_cb (GossipSession     *session,
 
 	type = gossip_contact_get_type (contact);
 	if (type != GOSSIP_CONTACT_TYPE_CONTACTLIST) {
-		d(g_print ("ContactList: Update to none-contact list "
-			   "contact (doing nothing)\n"));
+		DEBUG_MSG (("ContactList: Update to none-contact list "
+			   "contact (doing nothing)"));
 		return;
 	}
 
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (list));
 	presence = gossip_contact_get_active_presence (contact);
 
-	d(g_print ("ContactList: Contact updated: %s\n",
+	DEBUG_MSG (("ContactList: Contact updated: %s",
 		   gossip_contact_get_name (contact)));
 
 	if (!priv->show_offline && !gossip_contact_is_online (contact)) {
@@ -699,13 +715,18 @@ contact_list_contact_presence_updated_cb (GossipSession     *session,
 	GossipAccount         *account;
 	gdouble                seconds;
 
+	gboolean               is_composing;
+	const GdkPixbuf       *pixbuf;
+ 	GdkPixbuf             *pixbuf_composing;
+	GdkPixbuf             *pixbuf_presence;
+
 	priv = list->priv;
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (list));
 
 	type = gossip_contact_get_type (contact);
 	if (type != GOSSIP_CONTACT_TYPE_CONTACTLIST) {
-		d(g_print ("ContactList: Presence from none-contact list "
-			   "contact (doing nothing)\n"));
+		DEBUG_MSG (("ContactList: Presence from none-contact list "
+			   "contact (doing nothing)"));
 		return;
 	}
 
@@ -745,9 +766,9 @@ contact_list_contact_presence_updated_cb (GossipSession     *session,
 			do_set_refresh = TRUE;
 
 			set_model = TRUE;
-			d(g_print ("ContactList: Remove item (after timeout)\n")); 
+			DEBUG_MSG (("ContactList: Remove item (after timeout)")); 
 		} else {
-			d(g_print ("ContactList: Remove item (now)!\n")); 
+			DEBUG_MSG (("ContactList: Remove item (now)!")); 
 			contact_list_remove_contact (list, contact);
 		}
 	}
@@ -757,6 +778,10 @@ contact_list_contact_presence_updated_cb (GossipSession     *session,
 
 		if (seconds >= (SOUNDS_ENABLED_WAIT_TIME / 1000)) {
 			gossip_sound_play (GOSSIP_SOUND_ONLINE);
+
+#ifdef HAVE_LIBNOTIFY
+			gossip_notify_contact_online (contact);
+#endif
 		}
 
 		contact_list_add_contact (list, contact);
@@ -764,7 +789,7 @@ contact_list_contact_presence_updated_cb (GossipSession     *session,
 		if (priv->show_active) {
 			do_set_active = TRUE;
 
-			d(g_print ("ContactList: Set active (contact added)\n")); 
+			DEBUG_MSG (("ContactList: Set active (contact added)")); 
 		}
 
 	} else {
@@ -790,34 +815,46 @@ contact_list_contact_presence_updated_cb (GossipSession     *session,
 					str = "offline -> online"; 
 				}
 
-				d(g_print ("ContactList: Set active (contact updated %s)\n", str)); 
+				DEBUG_MSG (("ContactList: Set active (contact updated %s)", str)); 
 
 			} else {
 				/* was TRUE for presence updates */
 				/* do_set_active = FALSE;  */
 				do_set_refresh = TRUE;
 				
-				d(g_print ("ContactList: Set active (contact updated)\n")); 
+				DEBUG_MSG (("ContactList: Set active (contact updated)")); 
 			}
 		}
 
 		set_model = TRUE;
 	}
 
+
+	pixbuf_presence = gossip_pixbuf_for_contact (contact);
+	pixbuf_composing = gossip_pixbuf_from_stock (GOSSIP_STOCK_TYPING, 
+						     GTK_ICON_SIZE_MENU);
+
+	pixbuf = pixbuf_presence;
+
 	for (l = iters; l && set_model; l = l->next) {
-		GdkPixbuf *pixbuf;
-		
-		pixbuf = gossip_pixbuf_for_contact (contact);
-		
+		gtk_tree_model_get (model, l->data,
+				    COL_IS_COMPOSING, &is_composing,
+				    -1);
+
+		if (is_composing) {
+			pixbuf = pixbuf_composing;
+		}
+	
 		gtk_tree_store_set (GTK_TREE_STORE (model), l->data,
 				    COL_PIXBUF, pixbuf,
 				    COL_STATUS, gossip_contact_get_status (contact),
 				    COL_IS_ONLINE, now_online,
 				    -1);
-		
-		g_object_unref (pixbuf);
 	}
 
+	g_object_unref (pixbuf_presence); 
+	g_object_unref (pixbuf_composing); 
+
 	if (priv->show_active && do_set_active) {
 		contact_list_contact_set_active (list, contact, do_set_active, do_set_refresh);  
 
@@ -843,12 +880,70 @@ contact_list_contact_removed_cb (GossipSession     *session,
 				 GossipContact     *contact,
 				 GossipContactList *list)
 {
-	d(g_print ("ContactList: Contact removed: %s\n",
+	DEBUG_MSG (("ContactList: Contact removed: %s",
 		   gossip_contact_get_name (contact)));
 
 	contact_list_remove_contact (list, contact);
 }
 
+static void
+contact_list_contact_composing_cb (GossipSession     *session,
+				   GossipContact     *contact,
+				   gboolean           composing,
+				   GossipContactList *list)
+{
+	GossipContactListPriv *priv;
+	GtkTreeModel          *model;
+	GList                 *iters, *l;
+	GdkPixbuf             *pixbuf = NULL;
+
+	DEBUG_MSG (("ContactList: Contact %s typing:'%s'",
+		   composing ? "is" : "is not",
+		   gossip_contact_get_name (contact)));
+
+	priv = list->priv;
+
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (list));
+
+	if (! g_hash_table_lookup (priv->flash_table, contact)) {
+		if (composing) {
+			pixbuf = gossip_pixbuf_from_stock (GOSSIP_STOCK_TYPING, 
+							   GTK_ICON_SIZE_MENU);
+		} else {
+			pixbuf = gossip_pixbuf_for_contact (contact);
+		}
+	}
+	
+	iters = contact_list_find_contact (list, contact);
+	for (l = iters; l; l = l->next) {
+ 		GtkTreePath *path; 
+ 		GtkTreeIter *iter; 
+		
+		iter = l->data;
+
+		gtk_tree_store_set (GTK_TREE_STORE (model), iter,
+				    COL_IS_COMPOSING, composing,
+				    -1);
+
+		if (pixbuf) {
+			gtk_tree_store_set (GTK_TREE_STORE (model), iter,
+					    COL_PIXBUF, pixbuf,
+					    -1);
+		}
+
+		path = gtk_tree_model_get_path (model, iter); 
+		gtk_tree_model_row_changed (model, path, iter);  
+		gtk_tree_path_free (path); 
+	}
+
+	if (pixbuf) {
+		g_object_unref (pixbuf);
+	}
+	
+	g_list_foreach (iters, (GFunc)gtk_tree_iter_free, NULL);
+	g_list_free (iters);
+}
+
 static void
 contact_list_contact_set_active (GossipContactList *list, 
 				 GossipContact     *contact,
@@ -870,7 +965,7 @@ contact_list_contact_set_active (GossipContactList *list,
 		gtk_tree_store_set (GTK_TREE_STORE (model), iter,
 				    COL_IS_ACTIVE, active,
 				    -1);
-		d(g_print ("ContactList: Set item %s\n", active ? "active" : "inactive"));
+		DEBUG_MSG (("ContactList: Set item %s", active ? "active" : "inactive"));
 	
  		if (set_changed) { 
  			path = gtk_tree_model_get_path (model, iter); 
@@ -926,12 +1021,12 @@ contact_list_contact_active_cb (ShowActiveData *data)
 	if (data->remove && 
 	    !priv->show_offline && 
 	    !gossip_contact_is_online (data->contact)) {
-		d(g_print ("ContactList: Remove item (active timeout)!\n"));
+		DEBUG_MSG (("ContactList: Remove item (active timeout)!"));
 		contact_list_remove_contact (data->list,
 					     data->contact);
 	}
 
-	d(g_print ("ContactList: Setting contact to no longer be active\n"));
+	DEBUG_MSG (("ContactList: Setting contact to no longer be active"));
 	contact_list_contact_set_active (data->list, 
 					 data->contact,
 					 FALSE,
@@ -1017,6 +1112,7 @@ contact_list_get_group (GossipContactList *list,
 				    COL_NAME, name,
 				    COL_IS_GROUP, TRUE,
 				    COL_IS_ACTIVE, FALSE,
+				    COL_IS_COMPOSING, FALSE,
 				    -1);	
 	} else {
 		if (created) {
@@ -1087,6 +1183,7 @@ contact_list_add_contact (GossipContactList *list,
 				    COL_IS_GROUP, FALSE,
 				    COL_IS_ACTIVE, FALSE,
 				    COL_IS_ONLINE, gossip_contact_is_online (contact),
+				    COL_IS_COMPOSING, FALSE,
 				    -1);
 
 		g_object_unref (pixbuf);
@@ -1117,6 +1214,7 @@ contact_list_add_contact (GossipContactList *list,
 				    COL_IS_GROUP, FALSE,
 				    COL_IS_ACTIVE, FALSE,
 				    COL_IS_ONLINE, gossip_contact_is_online (contact),
+				    COL_IS_COMPOSING, FALSE,
 				    -1);
 
 		g_object_unref (pixbuf);
@@ -1200,6 +1298,7 @@ contact_list_create_model (GossipContactList *list)
 						    GOSSIP_TYPE_CONTACT,
 						    G_TYPE_BOOLEAN,
 						    G_TYPE_BOOLEAN,
+						    G_TYPE_BOOLEAN,
 						    G_TYPE_BOOLEAN));
 	
 	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
@@ -1333,14 +1432,14 @@ contact_list_drag_data_received (GtkWidget         *widget,
 	gboolean                 drag_del = FALSE;
 
 	id = (const gchar*) selection->data;
-	d(g_print ("ContactList: Received %s%s drag & drop contact from roster with id:'%s'\n", 
+	DEBUG_MSG (("ContactList: Received %s%s drag & drop contact from roster with id:'%s'", 
 		   context->action == GDK_ACTION_MOVE ? "move" : "", 
 		   context->action == GDK_ACTION_COPY ? "copy" : "", 
 		   id));
 
 	contact = gossip_session_find_contact (gossip_app_get_session (), id);
 	if (!contact) {
-		d(g_print ("ContactList: No contact found associated with drag & drop\n"));
+		DEBUG_MSG (("ContactList: No contact found associated with drag & drop"));
 		return;
 	}
 
@@ -2246,7 +2345,7 @@ contact_list_flash_timeout_func (FlashTimeoutData *t_data)
 	FlashData             *data;
 	gboolean               ret_val;
 	GossipContact         *contact;
-	GdkPixbuf             *pixbuf;
+	GdkPixbuf             *pixbuf = NULL;
 	GtkTreeModel          *model;
 	GList                 *l, *iters;
 	
@@ -2300,17 +2399,19 @@ contact_list_event_added_cb (GossipEventManager *manager,
 			     GossipContactList  *list)
 {
 	GossipContactListPriv *priv;
+	GossipMessage         *message;
 	GossipContact         *contact;
 	FlashData             *data;
 	FlashTimeoutData      *t_data;
 	
 	priv = list->priv;
 	
-	if (gossip_event_get_event_type (event) != GOSSIP_EVENT_NEW_MESSAGE) {
+	if (gossip_event_get_type (event) != GOSSIP_EVENT_NEW_MESSAGE) {
 		return;
 	}
 
-	contact = GOSSIP_CONTACT (gossip_event_get_data (event));
+	message = GOSSIP_MESSAGE (gossip_event_get_data (event));
+	contact = gossip_message_get_sender (message);
 	data = g_hash_table_lookup (priv->flash_table, contact);
 
 	if (data) {
@@ -2340,18 +2441,23 @@ contact_list_event_removed_cb (GossipEventManager *manager,
 {
 	GossipContactListPriv *priv;
 	FlashData             *data;
+	GossipMessage         *message;
 	GossipContact         *contact;
-	GdkPixbuf             *pixbuf;
+	const GdkPixbuf       *pixbuf;
+ 	GdkPixbuf             *pixbuf_composing;
+	GdkPixbuf             *pixbuf_presence;
 	GtkTreeModel          *model;
 	GList                 *iters, *l;
-	
-	if (gossip_event_get_event_type (event) != GOSSIP_EVENT_NEW_MESSAGE) {
+	gboolean               is_composing;
+
+	if (gossip_event_get_type (event) != GOSSIP_EVENT_NEW_MESSAGE) {
 		return;
 	}
 	
 	priv = list->priv;
 
-	contact = GOSSIP_CONTACT (gossip_event_get_data (event));
+	message = GOSSIP_MESSAGE (gossip_event_get_data (event));
+	contact = gossip_message_get_sender (message);
 
 	data = g_hash_table_lookup (priv->flash_table, contact);
 	if (!data) {
@@ -2366,17 +2472,31 @@ contact_list_event_removed_cb (GossipEventManager *manager,
 		return;
 	}
 	
-	pixbuf = gossip_pixbuf_for_contact (contact);
+	pixbuf_presence = gossip_pixbuf_for_contact (contact);
+	pixbuf_composing = gossip_pixbuf_from_stock (GOSSIP_STOCK_TYPING,
+						     GTK_ICON_SIZE_MENU);
+
+	pixbuf = pixbuf_presence;
+
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (list));
 
 	for (l = iters; l; l = l->next) {
+		gtk_tree_model_get (model, l->data,
+				    COL_IS_COMPOSING, &is_composing,
+				    -1);
+
+		if (is_composing) {
+			pixbuf = pixbuf_composing;
+		}
+
 		gtk_tree_store_set (GTK_TREE_STORE (model),
 				    l->data, 
 				    COL_PIXBUF, pixbuf,
 				    -1);
 	}
 
-	g_object_unref (pixbuf); 
+	g_object_unref (pixbuf_presence); 
+	g_object_unref (pixbuf_composing); 
  	
 	g_list_foreach (iters, (GFunc)gtk_tree_iter_free, NULL);
 	g_list_free (iters);
